// Csgparams.cpp
// This file contains the implementation of CSGParamsClass.

#include "stdafx.h"
#include "csgparam.h"
#include "procs.h"

#ifdef _DEBUG
#undef THIS_FILE
static char BASED_CODE THIS_FILE[] = __FILE__;
#endif

CSGParamsClass::CSGParamsClass()
//************************************************
// This is the default constructor for the class.
//************************************************
   {
   // Allocate BSTRs and VARIANTARGs, set default values, etc.
   ReplyDispatch = (LPDISPATCH)0;                             // Default is nothing (to be set later)
   AgeGen = SysAllocString(OLESTR("0"));                      // Use default AgeGen value of "0"
   CacheIndex = SysAllocString(OLESTR("0"));                  // Use default CacheIndex value of "0"
   CI = SysAllocString(OLESTR(""));                           // Use default of "" (to be set later)
   ClientContext = SysAllocString(OLESTR(""));                // Use default of ""
   ClientName = SysAllocString(OLESTR(""));                   // Use default of "" (to be set later)
   CSGName = SysAllocString(OLESTR("*"));                     // Use default of "*"
   Pathmon = SysAllocString(OLESTR("*"));                     // Use default Pathmon value of "*"
   ReplayKey = SysAllocString(OLESTR("1.1"));                 // Use default replay key value of "1.1"
   Message = SysAllocString(OLESTR(""));                      // Use default of "" (to be set later)
   Server = SysAllocString(OLESTR("*"));                      // Use default server value of "*"
   Tag = SysAllocString(OLESTR("TAG"));                       // Use default tag value of "TAG"
   Term = SysAllocString(OLESTR("*"));                        // Use default term value of "*"
   Status = 0;                                                // Use default of 0
   SubStatus = 0;                                             // Use default of 0
   Timeout = 60;                                              // Use default of 60 seconds
   RequestID = SysAllocString(OLESTR(""));                    // Use default of ""
   SetVariantFromBstr(&VAgeGen, &AgeGen);                     // Convert to variant
   SetVariantFromBstr(&VCacheIndex, &CacheIndex);             // Convert to variant
   SetVariantFromBstr(&VClientContext, &ClientContext);       // Convert to variant
   SetVariantFromBstr(&VCSGName, &CSGName);                   // Convert to variant
   SetVariantFromBstr(&VPathmon, &Pathmon);                   // Convert to variant
   SetVariantFromBstr(&VReplayKey, &ReplayKey);               // Convert to variant
   SetVariantFromBstr(&VServer, &Server);                     // Convert to variant
   SetVariantFromBstr(&VTag, &Tag);                           // Convert to variant
   SetVariantFromBstr(&VTerm, &Term);                         // Convert to variant
   VariantInit(&VTimeout);                                    // Init structure
   VTimeout.vt = VT_BYREF|VT_I4;                              // Pointer to long type
   VTimeout.plVal = &Timeout;                                 // Pointer to timeout value
   SetVariantFromBstr(&VRequestID, &RequestID);               // Convert to variant
   }  // CSGParamsClass::CSGParamsClass()


CSGParamsClass::CSGParamsClass(const CSGParamsClass& SourceObj)
//************************************************
// This is the copy constructor for the class.
//************************************************
   {
   // Allocate BSTRs and VARIANTARGs, set to passed object, etc.
   ReplyDispatch = SourceObj.ReplyDispatch;                   // Copy dispatch handle
   AgeGen = SysAllocString(SourceObj.AgeGen);                 // Copy
   CacheIndex = SysAllocString(SourceObj.CacheIndex);         // Copy
   CI = SysAllocString(SourceObj.CI);                         // Copy
   ClientContext = SysAllocString(SourceObj.ClientContext);   // Copy
   ClientName = SysAllocString(SourceObj.ClientName);         // Copy
   CSGName = SysAllocString(SourceObj.CSGName);               // Copy
   Pathmon = SysAllocString(SourceObj.Pathmon);               // Copy
   ReplayKey = SysAllocString(SourceObj.ReplayKey);           // Copy
   Message = SysAllocString(SourceObj.Message);               // Copy
   Server = SysAllocString(SourceObj.Server);                 // Copy
   Tag = SysAllocString(SourceObj.Tag);                       // Copy
   Term = SysAllocString(SourceObj.Term);                     // Copy
   Status = SourceObj.Status;                                 // Copy
   SubStatus = SourceObj.SubStatus;                           // Copy
   Timeout = SourceObj.Timeout;                               // Copy
   RequestID = SourceObj.RequestID;                           // Copy
   SetVariantFromBstr(&VAgeGen, &AgeGen);                     // Convert to variant
   SetVariantFromBstr(&VCacheIndex, &CacheIndex);             // Convert to variant
   SetVariantFromBstr(&VClientContext, &ClientContext);       // Convert to variant
   SetVariantFromBstr(&VCSGName, &CSGName);                   // Convert to variant
   SetVariantFromBstr(&VPathmon, &Pathmon);                   // Convert to variant
   SetVariantFromBstr(&VReplayKey, &ReplayKey);               // Convert to variant
   SetVariantFromBstr(&VServer, &Server);                     // Convert to variant
   SetVariantFromBstr(&VTag, &Tag);                           // Convert to variant
   SetVariantFromBstr(&VTerm, &Term);                         // Convert to variant
   VariantInit(&VTimeout);                                    // Init structure
   VTimeout.vt = VT_BYREF|VT_I4;                              // Pointer to long type
   VTimeout.plVal = &Timeout;                                 // Pointer to timeout value
   SetVariantFromBstr(&VRequestID, &RequestID);               // Convert to variant
   }  // CSGParamsClass::CSGParamsClass(const CSGParamsClass& SourceObj)


CSGParamsClass::~CSGParamsClass()
//************************************************
// This is the destructor for the class.
//************************************************
   {
   VariantClear(&VTimeout);
   VariantClear(&VTerm);
   VariantClear(&VTag);
   VariantClear(&VServer);
   VariantClear(&VReplayKey);
   VariantClear(&VPathmon);
   VariantClear(&VCSGName);
   VariantClear(&VClientContext);
   VariantClear(&VCacheIndex);
   VariantClear(&VAgeGen);
   VariantClear(&VRequestID);
   SysFreeString(Term);
   SysFreeString(Tag);
   SysFreeString(Server);
   SysFreeString(Message);
   SysFreeString(ReplayKey);
   SysFreeString(Pathmon);
   SysFreeString(CSGName);
   SysFreeString(ClientName);
   SysFreeString(ClientContext);
   SysFreeString(CI);
   SysFreeString(CacheIndex);
   SysFreeString(AgeGen);
   SysFreeString(RequestID);
   ReplyDispatch = (LPDISPATCH)0;
   }  // CSGParamsClass::~CSGParamsClass()

CSGParamsClass& CSGParamsClass::operator=(const CSGParamsClass& SourceObj)
//************************************************
// This is assignment method for the class.
//************************************************
   {
   // Copy BSTRs and reallocate VARIANTARGs, etc.
   ReplyDispatch = SourceObj.ReplyDispatch;                   // Copy dispatch handle
   SysReAllocString(&AgeGen, SourceObj.AgeGen);               // Copy
   SysReAllocString(&CacheIndex, SourceObj.CacheIndex);       // Copy
   SysReAllocString(&CI, SourceObj.CI);                       // Copy
   SysReAllocString(&ClientContext, SourceObj.ClientContext); // Copy
   SysReAllocString(&ClientName, SourceObj.ClientName);       // Copy
   SysReAllocString(&CSGName, SourceObj.CSGName);             // Copy
   SysReAllocString(&Pathmon, SourceObj.Pathmon);             // Copy
   SysReAllocString(&ReplayKey, SourceObj.ReplayKey);         // Copy
   SysReAllocString(&Message, SourceObj.Message);             // Copy
   SysReAllocString(&Server, SourceObj.Server);               // Copy
   SysReAllocString(&Tag, SourceObj.Tag);                     // Copy
   SysReAllocString(&Term, SourceObj.Term);                   // Copy
   Status = SourceObj.Status;                                 // Copy
   SubStatus = SourceObj.SubStatus;                           // Copy
   Timeout = SourceObj.Timeout;                               // Copy
   SysReAllocString(&RequestID, SourceObj.RequestID);         // Copy
   VAgeGen.pbstrVal = &AgeGen;                                // New string
   VCacheIndex.pbstrVal = &CacheIndex;                        // New string
   VClientContext.pbstrVal = &ClientContext;                  // New string
   VCSGName.pbstrVal = &CSGName;                              // New string
   VPathmon.pbstrVal = &Pathmon;                              // New string
   VReplayKey.pbstrVal = &ReplayKey;                          // New string
   VServer.pbstrVal = &Server;                                // New string
   VTag.pbstrVal = &Tag;                                      // New string
   VTerm.pbstrVal = &Term;                                    // New string
   VTimeout.plVal = &Timeout;                                 // New timeout value
   VRequestID.pbstrVal = &RequestID;                          // New string

   return *this;
   }  // CSGParamsClass& CSGParamsClass::operator=(const CSGParamsClass& SourceObj)


// ***** End of file CSGParam.cpp *****

